Disease Prediction
==================

**Disease Prediction using Multi-Omics Networks (DPMON):**

.. literalinclude:: ../examples/dpmon_example.py
   :language: python
   :caption: Example of Disease Prediction Workflow
